export default {
    "index": 4,
    "lineNumber": 1,
    "column": 5,
    "message": "Unexpected token 2"
};